@@ -18,7 +18,6 @@ class ErrorCodes(object):
         CountryCodeAlpha3IsNotAccepted = "91816"
         CountryCodeNumericIsNotAccepted = "91817"
         CountryNameIsNotAccepted = "91803"
-        ExtedAddressIsTooLong = "81804" # Deprecated
         ExtendedAddressIsInvalid = "91823"
         ExtendedAddressIsTooLong = "81804"
         FirstNameIsInvalid = "91819"
@@ -156,7 +155,6 @@ class ErrorCodes(object):
         FaxIsTooLong = "81607"
         FirstNameIsTooLong = "81608"
         IdIsInUse = "91609"
-        IdIsInvaild = "91610" # Deprecated
         IdIsInvalid = "91610"
         IdIsNotAllowed = "91611"
         IdIsRequired = "91613"
@@ -471,7 +469,6 @@ class ErrorCodes(object):
     class Transaction(object):
         AmountCannotBeNegative = "81501"
         AmountDoesNotMatch3DSecureAmount = "91585"
-        AmountDoesNotMatchIdealPaymentAmount = "915144"
         AmountIsInvalid = AmountFormatIsInvalid = "81503"
         AmountIsRequired = "81502"
         AmountIsTooLarge = "81528"
@@ -510,8 +507,6 @@ class ErrorCodes(object):
         FailedAuthAdjustmentHardDecline = "95602"
         FinalAuthSubmitForSettlementForDifferentAmount = "95601"
         HasAlreadyBeenRefunded = "91512"
-        IdealPaymentNotComplete = "815141"
-        IdealPaymentsCannotBeVaulted = "915150"
         PaymentInstrumentWithExternalVaultIsInvalid = "915176"
         DiscountAmountFormatIsInvalid = "915159"
         DiscountAmountCannotBeNegative = "915160"
@@ -522,17 +517,13 @@ class ErrorCodes(object):
         ShipsFromPostalCodeIsTooLong = "915165"
         ShipsFromPostalCodeIsInvalid = "915166"
         ShipsFromPostalCodeInvalidCharacters = "915167"
+        LineItemsExpected = "915158"
         MerchantAccountDoesNotMatch3DSecureMerchantAccount = "91584"
-        MerchantAccountDoesNotMatchIdealPaymentMerchantAccount = "915143"
         MerchantAccountDoesNotSupportMOTO = "91558"
         MerchantAccountDoesNotSupportRefunds = "91547"
         MerchantAccountIdDoesNotMatchSubscription = "915180"
         MerchantAccountIdIsInvalid = "91513"
-        MerchantAccountIsSusped = "91514" # Deprecated
         MerchantAccountIsSuspended = "91514"
-        MerchantAccountNameIsInvalid = "91513" # Deprecated
-        OrderIdDoesNotMatchIdealPaymentOrderId = "91503"
-        OrderIdIsRequiredWithIdealPayment = "91502"
         OrderIdIsTooLong = "91501"
         PayPalAuthExpired = "91579"
         PayPalNotEnabled = "91576"
@@ -582,24 +573,27 @@ class ErrorCodes(object):
         TaxAmountFormatIsInvalid = "81535"
         TaxAmountIsTooLarge = "81536"
         ThreeDSecureAuthenticationFailed = "81571"
-        ThreeDSecureTokenIsInvalid = "91568"
-        ThreeDSecureTransactionDataDoesntMatchVerify = "91570"
-        ThreeDSecureEciFlagIsRequired = "915113"
-        ThreeDSecureCavvIsRequired = "915116"
-        ThreeDSecureXidIsRequired = "915115"
-        ThreeDSecureEciFlagIsInvalid = "915114"
+        ThreeDSecureAuthenticationIdDoesntMatchNonceThreeDSecureAuthentication = "915198"
+        ThreeDSecureAuthenticationIdIsInvalid = "915196"
+        ThreeDSecureAuthenticationIdWithThreeDSecurePassThruIsInvalid = "915199"
         ThreeDSecureAuthenticationResponseIsInvalid = "915120"
-        ThreeDSecureDirectoryResponseIsInvalid = "915121"
         ThreeDSecureCavvAlgorithmIsInvalid = "915122"
+        ThreeDSecureCavvIsRequired = "915116"
+        ThreeDSecureDirectoryResponseIsInvalid = "915121"
+        ThreeDSecureEciFlagIsInvalid = "915114"
+        ThreeDSecureEciFlagIsRequired = "915113"
         ThreeDSecureMerchantAccountDoesNotSupportCardType = "915131"
+        ThreeDSecureTokenIsInvalid = "91568"
+        ThreeDSecureTransactionPaymentMethodDoesntMatchThreeDSecureAuthenticationPaymentMethod = "915197"
+        ThreeDSecureTransactionDataDoesntMatchVerify = "91570"
+        ThreeDSecureXidIsRequired = "915115"
+        TransactionSourceIsInvalid = "915133"
         TooManyLineItems = "915157"
-        LineItemsExpected = "915158"
         TypeIsInvalid = "91523"
         TypeIsRequired = "91524"
         UnsupportedVoiceAuthorization = "91539"
         UsBankAccountNonceMustBePlaidVerified = "915171"
         UsBankAccountNotVerified = "915172"
-        TransactionSourceIsInvalid = "915133"
 
         class ExternalVault(object):
             StatusIsInvalid = "915175"
@@ -704,7 +698,6 @@ class ErrorCodes(object):
             DescriptionIsTooLong = "95803"
             DiscountAmountFormatIsInvalid = "95804"
             DiscountAmountIsTooLarge = "95805"
-            DiscountAmountMustBeGreaterThanZero = "95806" # Deprecated as the amount may be zero.
             DiscountAmountCannotBeNegative = "95806"
             KindIsInvalid = "95807"
             KindIsRequired = "95808"
@@ -725,7 +718,6 @@ class ErrorCodes(object):
             UnitOfMeasureIsTooLarge = "95821"
             UnitTaxAmountFormatIsInvalid = "95824"
             UnitTaxAmountIsTooLarge = "95825"
-            UnitTaxAmountMustBeGreaterThanZero = "95826" # Deprecated as the amount may be zero.
             UnitTaxAmountCannotBeNegative = "95826"
             TaxAmountFormatIsInvalid = "95827"
             TaxAmountIsTooLarge = "95828"
